@@ -10,6 +10,8 @@ from .redditor import Redditor
 class Comment(RedditBase, InboxableMixin, UserContentMixin):
     """A class that represents a reddit comments."""
 
+    MISSING_COMMENT_MESSAGE = ('This comment does not appear to be in the '
+                               'comment tree')
     STR_FIELD = 'id'
 
     @property
@@ -37,15 +39,15 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
         """Return the Submission object this comment belongs to."""
         if not self._submission:  # Comment not from submission
             self._submission = self._reddit.submission(
-                self.link_id.split('_', 1)[1])
+                self._extract_submission_id())
         return self._submission
 
     @submission.setter
     def submission(self, submission):
         """Update the Submission associated with the Comment."""
-        assert self.name not in submission._comments_by_id
         submission._comments_by_id[self.name] = self
         self._submission = submission
+        # pylint: disable=not-an-iterable
         for reply in getattr(self, 'replies', []):
             reply.submission = submission
 
@@ -63,7 +65,6 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
 
     def __setattr__(self, attribute, value):
         """Objectify author, replies, and subreddit."""
-        # pylint: disable=redefined-variable-type
         if attribute == 'author':
             value = Redditor.from_data(self._reddit, value)
         elif attribute == 'replies':
@@ -76,6 +77,11 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
             value = self._reddit.subreddit(value)
         super(Comment, self).__setattr__(attribute, value)
 
+    def _extract_submission_id(self):
+        if 'context' in self.__dict__:
+            return self.context.rsplit('/', 4)[1]
+        return self.link_id.split('_', 1)[1]
+
     def parent(self):
         """Return the parent of the comment.
 
@@ -100,13 +106,38 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
            parent.refresh()
            print(parent.replies)  # Output is at least: [Comment(id='cklhv0f')]
 
+        .. warning:: Successive calls to :meth:`.parent()` may result in a
+           network request per call when the comment is not obtained through a
+           :class:`.Submission`. See below for an example of how to minimize
+           requests.
+
+        If you have a deeply nested comment and wish to most efficiently
+        discover its top-most :class:`.Comment` ancestor you can chain
+        successive calls to :meth:`.parent()` with calls to :meth:`.refresh()`
+        at every 9 levels. For example:
+
+        .. code:: python
+
+           comment = reddit.comment('dkk4qjd')
+           ancestor = comment
+           refresh_counter = 0
+           while not ancestor.is_root:
+               ancestor = ancestor.parent()
+               if refresh_counter % 9 == 0:
+                   ancestor.refresh()
+               refresh_counter += 1
+           print('Top-most Ancestor: {}'.format(ancestor))
+
+        The above code should result in 5 network requests to Reddit. Without
+        the calls to :meth:`.refresh` it would make at least 31 network
+        requests.
+
         """
         # pylint: disable=no-member
         if self.parent_id == self.submission.fullname:
             return self.submission
 
-        if '_comments' in self.submission.__dict__ \
-           and self.parent_id in self.submission._comments_by_id:
+        if self.parent_id in self.submission._comments_by_id:
             # The Comment already exists, so simply return it
             return self.submission._comments_by_id[self.parent_id]
         # pylint: enable=no-member
@@ -149,14 +180,30 @@ class Comment(RedditBase, InboxableMixin, UserContentMixin):
             comment_path = '{}_/{}'.format(
                 self.submission._info_path(),  # pylint: disable=no-member
                 self.id)
-        comment_list = self._reddit.get(comment_path)[1].children
+
+        # The context limit appears to be 8, but let's ask for more anyway.
+        comment_list = self._reddit.get(comment_path,
+                                        params={'context': 100})[1].children
         if not comment_list:
-            raise ClientException('Comment has been deleted')
-        comment = comment_list[0]
-        for reply in comment._replies:
-            reply.submission = self.submission
-        del comment.__dict__['_submission']  # Don't replace
+            raise ClientException(self.MISSING_COMMENT_MESSAGE)
+
+        # With context, the comment may be nested so we have to find it
+        comment = None
+        queue = comment_list[:]
+        while queue and (comment is None or comment.id != self.id):
+            comment = queue.pop()
+            if isinstance(comment, Comment):
+                queue.extend(comment._replies)
+
+        if comment.id != self.id:
+            raise ClientException(self.MISSING_COMMENT_MESSAGE)
+
+        if self._submission is not None:
+            del comment.__dict__['_submission']  # Don't replace if set
         self.__dict__.update(comment.__dict__)
+
+        for reply in comment_list:
+            reply.submission = self.submission
         return self
 
 
