@@ -781,7 +781,7 @@ class SubredditFlair(object):
 
         response = []
         url = API_PATH['flaircsv'].format(subreddit=self.subreddit)
-        while len(lines):
+        while lines:
             data = {'flair_csv': '\n'.join(lines[:100])}
             response.extend(self.subreddit._reddit.post(url, data=data))
             lines = lines[100:]
@@ -1412,7 +1412,7 @@ class ModeratorRelationship(SubredditRelationship):
             permissions, ModeratorRelationship.PERMISSIONS)
         return other_settings
 
-    def __call__(self, redditor=None):
+    def __call__(self, redditor=None):  # pylint: disable=arguments-differ
         """Return a list of Redditors who are moderators.
 
         :param redditor: When provided, return a list containing at most one
@@ -1444,6 +1444,7 @@ class ModeratorRelationship(SubredditRelationship):
             subreddit=self.subreddit)
         return self.subreddit._reddit.get(url, params=params)
 
+    # pylint: disable=arguments-differ
     def add(self, redditor, permissions=None, **other_settings):
         """Add or invite ``redditor`` to be a moderator of the subreddit.
 
@@ -1467,6 +1468,7 @@ class ModeratorRelationship(SubredditRelationship):
         """
         other_settings = self._handle_permissions(permissions, other_settings)
         super(ModeratorRelationship, self).add(redditor, **other_settings)
+    # pylint: enable=arguments-differ
 
     def invite(self, redditor, permissions=None, **other_settings):
         """Invite ``redditor`` to be a moderator of the subreddit.
@@ -1862,9 +1864,11 @@ class SubredditStylesheet(object):
             response = self.subreddit._reddit.post(url, data=data,
                                                    files={'file': image})
             if response['errors']:
-                assert response['errors'] == ['IMAGE_ERROR'], \
-                                             'Please file a bug with PRAW'
-                raise APIException(response['errors'][0], '', None)
+                error_type = response['errors'][0]
+                error_value = response.get('errors_values', [''])[0]
+                assert error_type in ['BAD_CSS_NAME', 'IMAGE_ERROR'], \
+                    'Please file a bug with PRAW'
+                raise APIException(error_type, error_value, None)
             return response
 
     def delete_header(self):
